package com.hzya.frame.nifiapi.operation;

import com.hzya.frame.nifiapi.model.joincreparamcontext.CreateParamContextJoin;
import com.hzya.frame.nifiapi.model.joinfindneedmodifycontroller.FindNeedModifyController;
import com.hzya.frame.nifiapi.model.joingetallcontrollerservice.ControllerServices19;

import java.util.List;

/**
 * Nifi基础操作封装
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.nifiapi.operation
 * @Project：fw-nifi
 * @name：BaseNifiOperation
 * @Date：2025/5/21 17:50
 * @Filename：BaseNifiOperation
 */
public interface IBaseOperation {
    /**
     * 实例化某个应用（对应nifi流程组id）
     *
     * @param appProcessGroupId        需要复制的流程组id(应用id)，比如Oracle应用id、Mysql应用id
     * @param parentProcessGroupId     流程组id(应用id)的父流程组id
     * @param copyTargetProcessGroupId 指定创建的流程组id
     * @return 返回流程组实例化id
     */
    String instantiateApp(String appProcessGroupId, String parentProcessGroupId, String copyTargetProcessGroupId) throws Exception;

    /**
     * 新增上下文参数环境，并绑定到指定的流程组
     *
     * @param createParamContextJoin 绑定上下文参数封装对象
     * @return 返回被绑定参数上下文的流程组id
     */
    String createParameterContextsBindingProcessGroup(CreateParamContextJoin createParamContextJoin) throws Exception;

    /**
     * 查询需要修改的控制器详情
     */
    List<ControllerServices19> getNeedModifyControllerServicesByProcessGroup(String processGroupId) throws Exception;

    /**
     * 查找某个流程组(应用app)内,带有"修改标记"的控制器服务，并更新控制器，从而达到实例化要求
     *
     * @param isThrowError true抛出异常，false不抛出异常、假设某个流程下有3个控制器服务需要修改，但入参只传了2个，在不满足业务需求且isError=true的情况下，就会抛出异常，主要是提醒业务调用代码
     */
    void findNeedModifyControllerAndChangesOccur(FindNeedModifyController findNeedModifyController, boolean isThrowError) throws Exception;

    /**
     * 批量创建连接关系
     */
}
